summaryrefslogtreecommitdiff
path: root/public/fpdfview.h
diff options
context:
space:
mode:
authorthestig <thestig@chromium.org>2016-11-23 15:25:48 -0800
committerCommit bot <commit-bot@chromium.org>2016-11-23 15:25:48 -0800
commita78ba6043eafc9fd05481e64c37002b487357bbf (patch)
tree17c346faee807b0ccf9660a51638f16f2e85e1c3 /public/fpdfview.h
parent4e847e36fe013bcfddf71c79221887a308b9fadb (diff)
downloadpdfium-a78ba6043eafc9fd05481e64c37002b487357bbf.tar.xz
Add FPDF_RenderPageBitmapWithMatrix API.
BUG=pdfium:522 Review-Url: https://codereview.chromium.org/2526473002
Diffstat (limited to 'public/fpdfview.h')
-rw-r--r--public/fpdfview.h32
1 files changed, 27 insertions, 5 deletions
diff --git a/public/fpdfview.h b/public/fpdfview.h
index 581951c7e2..403f4e46ec 100644
--- a/public/fpdfview.h
+++ b/public/fpdfview.h
@@ -596,11 +596,11 @@ DLLEXPORT void STDCALL FPDF_RenderPage(HDC dc,
// 1 (rotated 90 degrees clockwise)
// 2 (rotated 180 degrees)
// 3 (rotated 90 degrees counter-clockwise)
// flags - 0 for normal display, or combination of flags
// defined above. With FPDF_ANNOT flag, it renders all
// annotations that does not require user-interaction,
// which are all annotations except widget and popup
// annotations.
// Return value:
// None.
DLLEXPORT void STDCALL FPDF_RenderPageBitmap(FPDF_BITMAP bitmap,
@@ -612,6 +612,28 @@ DLLEXPORT void STDCALL FPDF_RenderPageBitmap(FPDF_BITMAP bitmap,
int rotate,
int flags);
+// Function: FPDF_RenderPageBitmapWithMatrix
+// Render contents of a page to a device independent bitmap.
+// Parameters:
+// bitmap - Handle to the device independent bitmap (as the
+// output buffer). The bitmap handle can be created
+// by FPDFBitmap_Create.
+// page - Handle to the page. Returned by FPDF_LoadPage
+// matrix - The transform matrix.
+// clipping - The rect to clip to.
+// flags - 0 for normal display, or combination of the Page
+// Rendering flags defined above. With the FPDF_ANNOT
+// flag, it renders all annotations that do not require
+// user-interaction, which are all annotations except
+// widget and popup annotations.
+// Return value:
+// None.
+DLLEXPORT void STDCALL FPDF_RenderPageBitmapWithMatrix(FPDF_BITMAP bitmap,
+ FPDF_PAGE page,
+ const FS_MATRIX* matrix,
+ const FS_RECTF* clipping,
+ int flags);
+
#ifdef _SKIA_SUPPORT_
DLLEXPORT FPDF_RECORDER STDCALL FPDF_RenderPageSkp(FPDF_PAGE page,
int size_x,
@@ -596,11 +596,11 @@ DLLEXPORT void STDCALL FPDF_RenderPage(HDC dc,
// 2 (rotated 180 degrees)
// 3 (rotated 90 degrees counter-clockwise)
-// flags - 0 for normal display, or combination of flags
-// defined above. With FPDF_ANNOT flag, it renders all
-// annotations that does not require user-interaction,
-// which are all annotations except widget and popup
-// annotations.
+// flags - 0 for normal display, or combination of the Page
+// Rendering flags defined above. With the FPDF_ANNOT
+// flag, it renders all annotations that do not require
+// user-interaction, which are all annotations except
+// widget and popup annotations.
// Return value:
// None.